# Options

## Custom Server

To change the host or port, set these, respectively:

- `SAPPY_HOST` (example: `0.0.0.0`)
- `SAPPY_PORT` (example: `4200`)

## Basic Authentication

To enable basic authentication to view the content, set:

- `SAPPY_BASIC_AUTH` (example: `username:password`)
